KeySender

Struct KeySender 

pub struct KeySender<K: Key, V: Value> { /* private fields */ }
Handle for sending and subscribing to messages by key.

Created via KeyStream::sender.

Implementations

Source

impl<K: Key, V: Value> KeySender<K, V>

pub async fn send(&self, key: &K, value: V) -> Result<usize, SendError<V>>

Send a value to all receivers subscribed to the given key.

Returns the number of receivers the message was sent to, or 0 if none.

pub async fn subscribe(&self, key: K) -> KeyReceiver<K, V>

Subscribe to messages for the given key.

Returns a KeyReceiver for receiving messages.

pub async fn n_keys(&self) -> usize

Get the number of keys currently tracked.

pub async fn key_capacity(&self) -> usize

Get the current capacity of the keys map.