KeyStream

Struct KeyStream 

pub struct KeyStream<K: Key, V: Value> { /* private fields */ }
The main entry point for key-based async message streaming.

Use KeyStream::new to create, then call KeyStream::sender to get a sender handle.

Example

use key_stream::KeyStream;
use tokio;
let key_stream = KeyStream::<i32, String>::new(10);
let sender = key_stream.sender();
let mut receiver = sender.subscribe(1).await;
sender.send(&1, "value".to_string()).await.unwrap();
assert_eq!(receiver.recv().await.unwrap(), "value".to_string());

Implementations

Source

impl<K: Key, V: Value> KeyStream<K, V>

pub fn new(broadcast_capacity: usize) -> Self

Create a new KeyStream with the given broadcast channel capacity per key.

pub fn sender(&self) -> KeySender<K, V>

Get a sender handle for publishing and subscribing to keys.

pub async fn n_keys(&self) -> usize

Get the number of keys currently tracked.

pub async fn key_capacity(&self) -> usize

Get the current capacity of the keys map.