KeyReceiver

Struct KeyReceiver 

pub struct KeyReceiver<K: Key, V: Value> { /* private fields */ }
A receiver for messages for a specific key.

Created via KeySender::subscribe.

Implementations

Source

impl<K: Key, V: Value> KeyReceiver<K, V>

pub async fn recv(&mut self) -> Result<V, RecvError>

Receive the next message for this key, waiting asynchronously. See, tokio::sync::broadcast::Receiver::recv for more details.

pub async fn try_recv(&mut self) -> Result<V, TryRecvError>

Try to receive the next message for this key without waiting.. See, tokio::sync::broadcast::Receiver::try_recv for more details.

pub fn blocking_recv(&mut self) -> Result<V, RecvError>

Receive the next message for this key, blocking the current thread. Only use in synchronous contexts. See, tokio::sync::broadcast::Receiver::blocking_recv for more details.

pub fn to_async_stream(self) -> impl Stream<Item = Result<V, RecvError>>

Consume this receiver and convert it into a stream of messages for this key.